<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:template match="image | link | text | tooltip | topic | textinput | spin | slider | radiobutton | checkbox | camerapanel | textarea | password | file | select | combo | button | number | progressbar | grid | settingSet | option | color | scheduleeditor | multichoice | tabarea | tab">
		<div class="window-element" data-name="{@id}">
			<xsl:apply-templates select="." mode="default" />
		</div>
	</xsl:template>

	<xsl:template name="windowItem">
		<xsl:attribute name="data-element"><xsl:value-of select="name()" /></xsl:attribute>
		<xsl:attribute name="data-id"><xsl:value-of select="@id" /></xsl:attribute>
		<xsl:attribute name="data-name"><xsl:value-of select="@id" /></xsl:attribute>
		<xsl:attribute name="data-type"><xsl:value-of select="@type" /></xsl:attribute>
		<xsl:attribute name="data-silent"><xsl:value-of select="@silent" /></xsl:attribute>
		<xsl:attribute name="data-style"><xsl:value-of select="@style" /></xsl:attribute>
		<xsl:attribute name="data-disabled"><xsl:value-of select="@disabled" /></xsl:attribute>
		<xsl:attribute name="data-state"><xsl:value-of select="@state" /></xsl:attribute>
		<xsl:attribute name="data-busy"><xsl:value-of select="@busy" /></xsl:attribute>
	</xsl:template>

	<xsl:template match="window">
	
		<div>
	
		<script type="text/javascript">
			// ks. window.js
			$(document).ready(windowLoaded("<xsl:value-of select="@id"/>"));
		</script>
		
		<div style="display:none;">
			<!-- Näiden inputtien tarkoitus on vastaanottaa selaimen mahdollisesti asettamat
				 kirjautumistietojen automaattitäydennykset, koska niitä ei haluta mihinkään
				 oikeasti käytettyihin elementteihin (ainakin jotkut selaimet automaattitäydentävät
				 ainoastaan ensimmäiset kirjautumistietokentät). -->
			<input type="text" id="my_username"/>
			<input type="password" id="my_password"/>
		</div>  
		
		<xsl:choose>
			<xsl:when test="@type = 'dialog'">
				<div class="window" data-title="{@title}" data-id="{@id}" data-type="{@type}" data-width="{@width}" data-height="{@height}" data-draggable="{@draggable}" data-style="{@style}"
					data-fullscreen="{@fullscreen}" data-resizable="{@resizable}" data-closeOnEscape="{@closeOnEscape}" data-showCloseButton="{@showCloseButton}" style="position: relative; left: 0; top: 0;">
					<xsl:apply-templates select="content" />
					<div class="window-busy" />
				</div>
			</xsl:when>
			<xsl:otherwise>	
				<div class="window" data-id="{@id}">
					<xsl:apply-templates select="content" />
				</div>
			</xsl:otherwise>
		</xsl:choose>
		
		</div>

	</xsl:template>
	
	<xsl:template match="tabarea">
		<div class="page-content ui-tabs">
			<ul class="ui-tabs-nav">
			<xsl:for-each select="tab">
				<xsl:if test="@title!=''">
					<li class="ui-tab">
						<a href="#tab-{@id}" class="ui-tabs-anchor">
							<xsl:value-of select="@title"/>
						</a>
					</li>
				</xsl:if>
			</xsl:for-each>
			</ul>
			
			<xsl:for-each select="tab">
				<div id="tab-{@id}" class="ui-widget-content ui-tabs-panel">
					<xsl:for-each select="*">
						<xsl:apply-templates select="." />
					</xsl:for-each>
				</div>
			</xsl:for-each>
		</div>
	</xsl:template>

	<xsl:template match="list">
		<ul class="window-list">
			<xsl:if test="@width != ''">
				<xsl:attribute name="style">width:<xsl:value-of select="@width" />px</xsl:attribute>
			</xsl:if>
			<xsl:for-each select="*">
				<li>
					<xsl:apply-templates select="." />
				</li>
			</xsl:for-each>
		</ul>
	</xsl:template>

	<xsl:template match="row">
		<div class="window-row" data-buttonrow="{@buttonrow}" data-optionrow="{@optionrow}">
			<xsl:attribute name="data-style"><xsl:value-of select="@style" /></xsl:attribute>
			<xsl:apply-templates select="*" />
		</div>
	</xsl:template>

	<xsl:template match="linebreak">
		<br />
	</xsl:template>

	<xsl:template match="content">
		<xsl:choose>
			<xsl:when test="@borderless='true'">
				<div class="page-content window-content" data-id="{@id}" data-style="{@style}" data-hidden="{@hidden}">
					<xsl:apply-templates select="*" />
				</div>
			</xsl:when>
			<xsl:otherwise>
				<div class="page-content window-content" data-id="{@id}" data-style="{@style}" data-hidden="{@hidden}">
				<xsl:choose>
					<xsl:when test="@title != ''">
						<div class="ui-widget-header ui-corner-top title-bar">
							<div class="window-content-title">
								<xsl:if test="@icon != ''">
									<div class="window-content-title-icon {@icon-class}" style="background-image: url('{@icon}')" />
								</xsl:if>
								<div class="window-content-title-text">
									<xsl:value-of select="@title" />
								</div>
							</div>
						</div>
						<div class="ui-widget-content ui-corner-bottom content-area">
							<xsl:apply-templates select="*" />
						</div>
					</xsl:when>
					<xsl:otherwise>
						<div class="ui-widget-content content-area window-no-border">
							<xsl:apply-templates select="*" />
						</div>
					</xsl:otherwise>
				</xsl:choose>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="image" mode="default">
		<img class="window-image {@icon-class}" src="{@src}" title="{@title}">
			<xsl:if test="@width != ''">
				<xsl:attribute name="width"><xsl:value-of select="@width" /></xsl:attribute>
				<xsl:attribute name="height"><xsl:value-of select="@height" /></xsl:attribute>
			</xsl:if>
		</img>
	</xsl:template>

	<xsl:template match="link" mode="default">
				<div class="window-text window-text-item ui-widget-header window-link">
			<xsl:call-template name="windowItem" />
			<a href="{@url}" target="{@target}"><xsl:value-of select="@label" /></a>
		</div>
	</xsl:template>

	<xsl:template match="text" mode="default">
				<div class="window-text window-text-item" data-style="{@style}">
			<xsl:call-template name="windowItem" />
			<xsl:value-of select="@text" />
		</div>
	</xsl:template>
	
	<xsl:template match="tooltip" mode="default">
		<span class="window-tooltip" title="{@text}" />
	</xsl:template>
	
	<xsl:template match="topic" mode="default">
		<div class="ui-widget-header ui-corner-top">
			<xsl:value-of select="@topic" />
			<xsl:if test="@help != ''">
				<span class="window-topic-help tooltip" style="display: inline-block; float:right;" title="{@help}" />
			</xsl:if>
		</div>
	</xsl:template>

	<xsl:template match="textinput | password" mode="default">
		<xsl:if test="@label != ''">
			<div>
				<xsl:value-of select="@label" />
			</div>
		</xsl:if>
		<input class="window-input window-item window-text-input" type="{name()}" value="{@value}" size="{@size}" placeholder="{@placeholder}" data-controltype="{@controltype}" data-constantchangeupdates="{@constantChangeUpdates}">
			<xsl:if test="@readonly = 'true'">
				<xsl:attribute name="readonly">readonly</xsl:attribute>
			</xsl:if>
			<xsl:if test="name() = 'textinput'">
				<xsl:attribute name="type">text</xsl:attribute>
			</xsl:if>
			<xsl:call-template name="windowItem" />
		</input>
	</xsl:template>
	
	<xsl:template match="spin" mode="default">
		<div>
			<xsl:value-of select="@label"/>
		</div>
		
		<input class="window-input window-item window-spinner" type="text" data-min="{@min}" data-max="{@max}" value="{@value}">
			<xsl:call-template name="windowItem" />
			<xsl:value-of select="@info"/>
		</input>
	</xsl:template>

	<xsl:template match="slider" mode="default">
		<div>
			<xsl:value-of select="@label"/>
		</div>
		
		<div>
			<input class="window-input window-item window-slider-spinner" type="text" data-min="{@min}" data-max="{@max}" value="{@value}" style="margin-right: 10px">
				<xsl:call-template name="windowItem" />
			</input>

			<div class="window-input window-item window-slider" data-min="{@min}" data-max="{@max}" data-value="{@value}">
				<xsl:call-template name="windowItem" />
			</div>
		</div>
	</xsl:template>

	<xsl:template match="checkbox" mode="default">
		<div>
		<input class="window-input window-item window-checkbox" type="checkbox">
			<xsl:if test="@checked = 'true'">
				<xsl:attribute name="checked">checked</xsl:attribute>
			</xsl:if>
			<xsl:call-template name="windowItem" />
		</input>
		<xsl:value-of select="@label" />
		</div>
	</xsl:template>
	
	<xsl:template match="radiobutton" mode="default">
		<input class="ui-state-default window-input window-item" type="radio" name="{@name}" value="{@value}" readonly="{@readonly}">
			<xsl:if test="@checked = 'true'">
				<xsl:attribute name="checked">checked</xsl:attribute>
			</xsl:if>
			<xsl:call-template name="windowItem" />
		</input>
		<label>
			<xsl:value-of select="@label" />
		</label>
	</xsl:template>
	
	<xsl:template match="textarea" mode="default">
		<textarea class="window-item window-input" style="width:{@width}px" rows="{@rows}">
			<xsl:if test="@readonly = 'true'">
				<xsl:attribute name="readonly">readonly</xsl:attribute>
			</xsl:if>
			<xsl:call-template name="windowItem" />
			<xsl:value-of select="@text" />
		</textarea>
	</xsl:template>

	<xsl:template match="file" mode="default">
		<form class="window-item" enctype="multipart/form-data">
			<input class="ui-state-default window-file" name="file" type="file" style="width:100%; max-width: 100%;" size="100" accept="{@accept}" />
		</form>
		
		<br></br>
		
		<input class="ui-button ui-state-default window-file-submit window-input window-item" type="button" value="{@submitText}">
			<xsl:call-template name="windowItem" />
		</input>
	</xsl:template>

	<xsl:template match="select" mode="default">
		<select class="window-input window-item window-select" value="{@value}" size="{@size}">
		<xsl:call-template name="windowItem" />
		
		<xsl:if test="@multiple = 'true'">
			<xsl:attribute name="multiple">multiple</xsl:attribute>
		</xsl:if>
		
		<xsl:for-each select="choice">
			<option class="window-item" value="{@id}" data-disabled="{@disabled}">
				<xsl:if test="@id = ../@selected or @selected = 'true'">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				<xsl:value-of select="@label" />
			</option>
		</xsl:for-each>	
		
		</select>
	</xsl:template>
	
	<xsl:template match="combo" mode="default">
		<input type="text" class="window-input window-item window-combo" list="window-combo-options-{@id}" value="{@selected}">
			<xsl:call-template name="windowItem" />
		</input>
		<datalist id="window-combo-options-{@id}">
			<xsl:for-each select="option">
				<option data-id="{@id}" value="{@label}" />
			</xsl:for-each>	
		</datalist>
	</xsl:template>

	<xsl:template match="button" mode="default">
		<input class="ui-button ui-state-default window-input window-item window-button" type="button" value="{@label}" data-controltype="{@controltype}" data-style="{@style}">
			<xsl:call-template name="windowItem" />
		</input>
	</xsl:template>
	
	<xsl:template match="color" mode="default">
		<div class="window-color" data-style="{@style}">
			<input class="ui-button ui-state-default window-input window-item" type="color" value="#{@value}">
				<xsl:call-template name="windowItem" />
			</input>
		</div>
	</xsl:template>

	<xsl:template match="number" mode="default">
		<div>
			<div class="window-text">
				<xsl:value-of select="@label" />
			</div>
			<input class="window-input window-item window-number" type="number" min="{@min}" max="{@max}" value="{@value}">
				<xsl:call-template name="windowItem" />
			</input>
		</div>
	</xsl:template>

	<xsl:template match="progressbar" mode="default">
		<div class="window-item window-progressbar" data-indeterminate="{@indeterminate}">
			<xsl:call-template name="windowItem" />
		</div>
	</xsl:template>

	<xsl:template match="grid" mode="default">
		<div class="window-grid window-item">
			<xsl:call-template name="windowItem" />
			
			<div style="position: relative;">
				<table id="{//window/@id}-{@id}" class="window-grid-table" data-width="{@width}" data-height="{@height}" data-selectable="{@selectable}" data-multiselect="{@multiselect}"></table>
				
				<xsl:for-each select="column">
				<div class="window-column" data-id="{@id}" data-name="{@name}" data-width="{@width}" data-hidden="{@hidden}" data-editable="{@editable}" data-edittype="{@edittype}" data-editvalues="{@editvalues}" data-button="{@button}" style="display: none;" />
				</xsl:for-each>
				
				<div class="window-busy" />
			</div>

		</div>
	</xsl:template>
	
	<xsl:template match="camerapanel" mode="default">
		<div class="window-item window-camerapanel" data-name="{@name}" data-label="{@label}" data-mask="{@mask}" data-mode="{@mode}" data-selectedarea="{@selectedarea}">
			<xsl:call-template name="windowItem" />
			
			<xsl:for-each select="areas/area">
				<div class="window-camerapanel-area" data-id="{@id}" data-type="{@type}" data-title="{@title}" data-points="{@points}" style="display: none;" />
			</xsl:for-each>	
		</div>
	</xsl:template>
	
	<xsl:template match="scheduleeditor" mode="default">
		<div class="window-item window-scheduleeditor" data-value="{@value}" data-timeday="{@_timeday}" data-day0="{@_day0}" data-day1="{@_day1}" data-day2="{@_day2}"
			data-day3="{@_day3}" data-day4="{@_day4}" data-day5="{@_day5}" data-day6="{@_day6}">
			<xsl:call-template name="windowItem" />
		</div>
	</xsl:template>
	
	<xsl:template match="multichoice" mode="default">
		<div>
			<div class="ui-widget-content window-item window-multichoice" data-width="{@width}" data-height="{@height}">
				<xsl:call-template name="windowItem" />
				<ul>
					<xsl:for-each select="choice">
						<li>
							<div>
								<input class="ui-state-default window-multichoice-choice" type="checkbox" value="{@id}">
								<xsl:if test="@selected = 'true'">
									<xsl:attribute name="checked">"checked"</xsl:attribute>
								</xsl:if>
								</input>
								<xsl:value-of select="@name" />
							</div>
						</li>
					</xsl:for-each>
				</ul>
			</div>
			<xsl:if test="@_selectall != ''">
				<br></br>
				<input class="ui-button ui-state-default window-multichoice-selectall" type="button" value="{@_selectall}"></input>
			</xsl:if>
		</div>
	</xsl:template>

</xsl:stylesheet>
